@@ -67,9 +67,10 @@ class Objective:
             ObjectiveTerm.from_description(term, objective=self, name=name) for name, term in term_kwargs.items()
         ]
         self.terms: th.List[ObjectiveTerm] = term_args + term_kwargs
-        self.__rename_terms(terms=self.terms)  # to make sure all terms have unique names
+        # to make sure all terms have unique names
+        self.__rename_terms(terms=self.terms)
         # initialize the latches
-        self.latch, self.results_latch, self.factors_latch = {}, {}, {}
+        self.inputs_latch, self.latch, self.results_latch, self.factors_latch = {}, {}, {}, {}
 
     @property
     def results(self) -> ResultsDict:
@@ -158,7 +159,8 @@ class Objective:
         factors_applied_values = [
             term.apply_factor(term_value=self.results_latch[term.name], factor_value=self.factors_latch[term.name])
             for term in self.terms
-            if term.name in self.results_latch  # only reduce terms that contribute to the loss
+            # only reduce terms that contribute to the loss
+            if term.name in self.results_latch
         ]
         return sum(factors_applied_values)
 
@@ -166,6 +168,7 @@ class Objective:
         self, *args, return_factors: bool = False, **kwargs
     ) -> th.Union[ResultsDict, th.Tuple[ResultsDict, FactorsDict]]:
         self._forget()  # clear the latches
+        self.inputs_latch.update(kwargs)  # save all the input arguments in the latch
         self.process_terms_results(*args, **kwargs)  # process the terms
         self.factors_latch = {
             term.name: term.factor(*args, **kwargs) for term in self.terms if term.name in self.results_latch
